
// openpluginlib - A plugin interface to openlibraries.

// Copyright (C) 2005-2006 Editopia Inc.
// Released under the LGPL.
// For more information, see http://www.openlibraries.org.

#ifndef PY_INC_
#define PY_INC_

namespace olib { namespace openpluginlib { namespace detail {

void py_geometry( );
void py_single_property( );
void py_multi_property( );
void py_string( );
void py_openpluginlib( );
void py_pcos_key();
void py_pcos_observer();
void py_pcos_subject();
void py_pcos_property();
void py_pcos_any();
void py_pcos_property_container();
void py_pcos_visitor();

} } }

#endif
